"""
    Ory APIs

    Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed with a valid Personal Access Token. Public APIs are mostly used in browsers.   # noqa: E501

    The version of the OpenAPI document: v0.0.1-alpha.145
    Contact: support@ory.sh
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import ory_client
from ory_client.model.identity_schema_location import IdentitySchemaLocation


class TestIdentitySchemaLocation(unittest.TestCase):
    """IdentitySchemaLocation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testIdentitySchemaLocation(self):
        """Test IdentitySchemaLocation"""
        # FIXME: construct object with mandatory attributes with example values
        # model = IdentitySchemaLocation()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Ory APIs

    Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed with a valid Personal Access Token. Public APIs are mostly used in browsers.   # noqa: E501

    The version of the OpenAPI document: v0.0.1-alpha.145
    Contact: support@ory.sh
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import ory_client
from ory_client.model.submit_self_service_settings_flow_with_lookup_method_body import SubmitSelfServiceSettingsFlowWithLookupMethodBody
from ory_client.model.submit_self_service_settings_flow_with_oidc_method_body import SubmitSelfServiceSettingsFlowWithOidcMethodBody
from ory_client.model.submit_self_service_settings_flow_with_password_method_body import SubmitSelfServiceSettingsFlowWithPasswordMethodBody
from ory_client.model.submit_self_service_settings_flow_with_profile_method_body import SubmitSelfServiceSettingsFlowWithProfileMethodBody
from ory_client.model.submit_self_service_settings_flow_with_totp_method_body import SubmitSelfServiceSettingsFlowWithTotpMethodBody
from ory_client.model.submit_self_service_settings_flow_with_web_authn_method_body import SubmitSelfServiceSettingsFlowWithWebAuthnMethodBody
globals()['SubmitSelfServiceSettingsFlowWithLookupMethodBody'] = SubmitSelfServiceSettingsFlowWithLookupMethodBody
globals()['SubmitSelfServiceSettingsFlowWithOidcMethodBody'] = SubmitSelfServiceSettingsFlowWithOidcMethodBody
globals()['SubmitSelfServiceSettingsFlowWithPasswordMethodBody'] = SubmitSelfServiceSettingsFlowWithPasswordMethodBody
globals()['SubmitSelfServiceSettingsFlowWithProfileMethodBody'] = SubmitSelfServiceSettingsFlowWithProfileMethodBody
globals()['SubmitSelfServiceSettingsFlowWithTotpMethodBody'] = SubmitSelfServiceSettingsFlowWithTotpMethodBody
globals()['SubmitSelfServiceSettingsFlowWithWebAuthnMethodBody'] = SubmitSelfServiceSettingsFlowWithWebAuthnMethodBody
from ory_client.model.submit_self_service_settings_flow_body import SubmitSelfServiceSettingsFlowBody


class TestSubmitSelfServiceSettingsFlowBody(unittest.TestCase):
    """SubmitSelfServiceSettingsFlowBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSubmitSelfServiceSettingsFlowBody(self):
        """Test SubmitSelfServiceSettingsFlowBody"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SubmitSelfServiceSettingsFlowBody()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Ory APIs

    Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed with a valid Personal Access Token. Public APIs are mostly used in browsers.   # noqa: E501

    The version of the OpenAPI document: v0.0.1-alpha.145
    Contact: support@ory.sh
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import ory_client
from ory_client.model.identity_credentials import IdentityCredentials
from ory_client.model.identity_state import IdentityState
from ory_client.model.recovery_address import RecoveryAddress
from ory_client.model.verifiable_identity_address import VerifiableIdentityAddress
globals()['IdentityCredentials'] = IdentityCredentials
globals()['IdentityState'] = IdentityState
globals()['RecoveryAddress'] = RecoveryAddress
globals()['VerifiableIdentityAddress'] = VerifiableIdentityAddress
from ory_client.model.identity import Identity


class TestIdentity(unittest.TestCase):
    """Identity unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testIdentity(self):
        """Test Identity"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Identity()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Ory APIs

    Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed with a valid Personal Access Token. Public APIs are mostly used in browsers.   # noqa: E501

    The version of the OpenAPI document: v0.0.1-alpha.145
    Contact: support@ory.sh
    Generated by: https://openapi-generator.tech
"""


import unittest

import ory_client
from ory_client.api.metadata_api import MetadataApi  # noqa: E501


class TestMetadataApi(unittest.TestCase):
    """MetadataApi unit test stubs"""

    def setUp(self):
        self.api = MetadataApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_version(self):
        """Test case for get_version

        Return Running Software Version.  # noqa: E501
        """
        pass

    def test_is_alive(self):
        """Test case for is_alive

        Check HTTP Server Status  # noqa: E501
        """
        pass

    def test_is_ready(self):
        """Test case for is_ready

        Check HTTP Server and Database Status  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
